@@ -6,6 +6,7 @@
 
 """Extractors for https://www.fanbox.cc/"""
 
+import re
 from .common import Extractor, Message
 from .. import text
 
@@ -67,6 +68,31 @@ class FanboxExtractor(Extractor):
                 post["html"] = content_body["html"]
             if post["type"] == "article":
                 post["articleBody"] = content_body.copy()
+            if "blocks" in content_body:
+                content = []  # text content
+                images = []   # image IDs in 'body' order
+
+                append = content.append
+                append_img = images.append
+                for block in content_body["blocks"]:
+                    if "text" in block:
+                        append(block["text"])
+                    if "links" in block:
+                        for link in block["links"]:
+                            append(link["url"])
+                    if "imageId" in block:
+                        append_img(block["imageId"])
+
+                if images and "imageMap" in content_body:
+                    # reorder 'imageMap' (#2718)
+                    image_map = content_body["imageMap"]
+                    content_body["imageMap"] = {
+                        image_id: image_map[image_id]
+                        for image_id in images
+                        if image_id in image_map
+                    }
+
+                post["content"] = "\n".join(content)
 
         post["date"] = text.parse_datetime(post["publishedDatetime"])
         post["text"] = content_body.get("text") if content_body else None
@@ -78,6 +104,7 @@ class FanboxExtractor(Extractor):
         num = 0
         cover_image = post.get("coverImageUrl")
         if cover_image:
+            cover_image = re.sub("/c/[0-9a-z_]+", "", cover_image)
             final_post = post.copy()
             final_post["isCoverImage"] = True
             final_post["fileUrl"] = cover_image
@@ -230,7 +257,6 @@ class FanboxCreatorExtractor(FanboxExtractor):
 
     def posts(self):
         url = "https://api.fanbox.cc/post.listCreator?creatorId={}&limit=10"
-
         return self._pagination(url.format(self.creator_id))
 
 
@@ -269,6 +295,23 @@ class FanboxPostExtractor(FanboxExtractor):
                 "hasAdultContent": True
             },
         }),
+        # 'content' metadata (#3020)
+        ("https://www.fanbox.cc/@official-en/posts/4326303", {
+            "keyword": {
+                "content": r"re:(?s)^Greetings from FANBOX.\n \nAs of Monday, "
+                           r"September 5th, 2022, we are happy to announce "
+                           r"the start of the FANBOX hashtag event "
+                           r"#MySetupTour ! \nAbout the event\nTo join this "
+                           r"event .+ \nPlease check this page for further "
+                           r"details regarding the Privacy & Terms.\n"
+                           r"https://fanbox.pixiv.help/.+/10184952456601\n\n\n"
+                           r"Thank you for your continued support of FANBOX.$",
+            },
+        }),
+        # imageMap file order (#2718)
+        ("https://mochirong.fanbox.cc/posts/3746116", {
+            "url": "c92ddd06f2efc4a5fe30ec67e21544f79a5c4062",
+        }),
     )
 
     def __init__(self, match):
